joint_prompt: Generate connector prompt

View source: R/llmjoin.R

joint_promptR Documentation

Generate connector prompt

Description

Generate a prompt to guide the LLM in generating a joint for data frame joining, leveraging the two key columns from the tables to be connected. As of 2025/04/10, DeepSeek R1 and gpt-4.1-mini showed the best result; other LLMs might fabricate non-existent data in the result.

Usage

joint_prompt(x, y)

Arguments

x

1-column data.frame or vector of characters, left hand side of the join

y

1-column data.frame or vector of characters, right hand side of the join

Value

A character string containing the matching prompt.

Examples

joint_prompt(
  data.frame(x = c("01","02","04")),
  data.frame(y = c("January","Feb","May"))
)

llmjoin documentation built on June 17, 2026, 1:08 a.m.