| joint_prompt | R Documentation |
Generate a prompt to guide the LLM in generating a joint for data frame joining, leveraging the two key columns from the tables to be connected. As of 2025/04/10, DeepSeek R1 and gpt-4.1-mini showed the best result; other LLMs might fabricate non-existent data in the result.
joint_prompt(x, y)
x |
1-column data.frame or vector of characters, left hand side of the join |
y |
1-column data.frame or vector of characters, right hand side of the join |
A character string containing the matching prompt.
joint_prompt(
data.frame(x = c("01","02","04")),
data.frame(y = c("January","Feb","May"))
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.